//Import necessary modules from D3
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

// Formatting the total value to show on the Linechart
const xAxisTickFormat = number =>
    format('.3s')(number)

const render = data => { 
// Assigning X axis data   
  const xValue = d => d.Year; 
  const xAxisLabel = 'Year';
// Assigning Y axis data 
  const yValue = d => d.Global_Sales;
  const yAxisLabel = 'Sales in Millions';
  
  const margin = { top: 10, right: 40, bottom: 88, left: 120 };//mm manière que CSS
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top-30 - margin.bottom-20;
  
  // Determing the Scale for X axis
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth]) 
    .nice(); //round values out
  
// Determing the Scale for Y axis  
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

// POsitioning the svg element  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
 // Assigning values to x axis  
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(20);
 // Assigning values to y axis  
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10)
  ;
  	
  
  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 6)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

// Drawing a line and adding it to svg 
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))
};

// Loading and Parsing CSV data
csv('https://gist.githubusercontent.com/gunasindhuja/0923d3f66a4bafe17702ca80e214800d/raw/ed35daab05cb3b57ccb981c7914023f7c6d11691/GameSalesSorted.csv')
  .then(data => {
    data.forEach(d => {
    	d.Global_Sales = +d.Global_Sales;
//Formatting to retrieve year from the date
     d.Year = new Date(d.Year);
    });
    const slicedData = data.slice(0, 180); // slice the first 100 data points
    
    render(slicedData);
  })